@@ -76,6 +76,8 @@ fun advancedTab(
     addSetUserId(this, settings)
 
     addEasterEggsCheckBox(this, settings)
+
+    addEnlargeNotificationsCheckBox(this, settings)
 }
 
 private fun addCutoutCheckbox(table: Table, optionsPopup: OptionsPopup) {
@@ -116,7 +118,6 @@ private fun addAutosaveTurnsSelectBox(table: Table, settings: GameSettings) {
 
     autosaveTurnsSelectBox.onChange {
         settings.turnsBetweenAutosaves = autosaveTurnsSelectBox.selected
-        settings.save()
     }
 }
 
@@ -207,7 +208,6 @@ private fun addFontSizeMultiplier(
         initial = settings.fontSizeMultiplier
     ) {
         settings.fontSizeMultiplier = it
-        settings.save()
     }
     fontSizeSlider.onChange {
         if (!fontSizeSlider.isDragging)
@@ -223,7 +223,6 @@ private fun addMaxZoomSlider(table: Table, settings: GameSettings) {
         initial = settings.maxWorldZoomOut
     ) {
         settings.maxWorldZoomOut = it
-        settings.save()
         if (GUI.isWorldLoaded())
             GUI.getMap().reloadMaxZoom()
     }
@@ -333,7 +332,6 @@ private fun addSetUserId(table: Table, settings: GameSettings) {
                     "Take user ID from clipboard"
                 ) {
                     settings.multiplayer.userId = clipboardContents
-                    settings.save()
                     idSetLabel.setFontColor(Color.WHITE).setText("ID successfully set!".tr())
                 }.open(true)
                 idSetLabel.isVisible = true
@@ -350,3 +348,9 @@ private fun addEasterEggsCheckBox(table: Table, settings: GameSettings) {
     val checkbox = "Enable Easter Eggs".toCheckBox(settings.enableEasterEggs) { settings.enableEasterEggs = it }
     table.add(checkbox).colspan(2).row()
 }
+
+private fun addEnlargeNotificationsCheckBox(table: Table, settings: GameSettings) {
+    val checkbox = "Enlarge selected notifications"
+        .toCheckBox(settings.enlargeSelectedNotification) { settings.enlargeSelectedNotification = it }
+    table.add(checkbox).colspan(2).row()
+}
